@@ -463,7 +463,7 @@ class NamelistName(SortedDict):
             tmp=NamelistName(index_offset=self.index_offset)
             tmp.update(value)
             value=tmp
-        return super(NamelistName,self).__setitem__(key,value)
+        return super().__setitem__(key,value)
 
     def __getitem__(self, key):
         key=self._keyCaseInsensitive(key)
@@ -476,7 +476,7 @@ class NamelistName(SortedDict):
             index=None
 
         try:
-            tmp=super(NamelistName, self).__getitem__(key)
+            tmp=super().__getitem__(key)
         except KeyError:
             raise
 
