@@ -121,7 +121,7 @@ def exportDataset(data, path, complex_dim='i', *args, **kw):
     ida = DataArray([0, 1], coords={complex_dim: [0, 1]}, dims=(complex_dim,))
     rda = DataArray([1, 0], coords={complex_dim: [0, 1]}, dims=(complex_dim,))
     for k, v in list(data.data_vars.items()):
-        if np.any(np.iscomplex(v.values)) or (hasattr(v.values, 'dtype') and v.values.dtype == np.complex):
+        if np.any(np.iscomplex(v.values)) or (hasattr(v.values, 'dtype') and v.values.dtype == complex):
             data[k] = v.real * rda + v.imag * ida
 
     # Use the Dataset.to_netcdf method
@@ -526,7 +526,13 @@ class OMFITncDataset(OMFITobject, OMFITdataset):
             kw['exportDataset_kw'] = exportDataset_kw
         OMFITobject.__init__(self, filename, **kw)
         self.lock = lock
-        self.dynaLoad = True
+        if data_vars or coords or attrs:
+            if not (os.stat(self.filename).st_size):
+                self.dynaLoad = False
+            else:
+                raise ValueError('Cannot specify `filename` with data and `data_vars`, or `coords` or `attrs` at the same time')
+        else:
+            self.dynaLoad = True
         OMFITdataset.__init__(self, data_vars=data_vars, coords=coords, attrs=attrs)
         self._loaded_hash = hash(())
         self._dynamic_keys = []
