@@ -19,7 +19,6 @@ import numpy as np
 
 __all__ = ['OMFITmars', 'OMFITnColumns', 'OMFITmarsProfile']
 
-
 class OMFITmars(SortedDict, OMFITobject):
     """
     Class used to interface with MARS results directory
@@ -293,7 +292,8 @@ class OMFITmars(SortedDict, OMFITobject):
 
     def read_RESULTS(self, filename):
         with open(filename) as fin:
-            tmp = list(map(float, fin.readline().split()))
+            lines = fin.read().splitlines()
+            tmp = list(map(float, lines[-1].split()))
         if len(tmp):
             self[self.sim]['NITR'] = xarray.DataArray(tmp[1])
             self[self.sim]['TALPHA1'] = xarray.DataArray(complex(tmp[2], tmp[3]))
@@ -1005,7 +1005,10 @@ class OMFITmars(SortedDict, OMFITobject):
         )
         for item in mapper:
             if os.path.exists(self.filename + os.sep + item):
-                mapper[item](self.filename + os.sep + item)
+                try:
+                    mapper[item](self.filename + os.sep + item)
+                except Exception as _excp:
+                    print(f'Problem parsing {item}: {_excp}')
 
     """
     Plotting methods
@@ -1396,7 +1399,6 @@ class OMFITmars(SortedDict, OMFITobject):
         ax.legend(loc=0)
         fig.tight_layout()
 
-
 class OMFITnColumns(SortedDict, OMFITascii):
     r"""
     OMFIT class used to interface with n-columns input files
@@ -1448,11 +1450,9 @@ class OMFITnColumns(SortedDict, OMFITascii):
             pyplot.ylabel(self._OMFITkeyName)
             pyplot.tight_layout()
 
-
 class OMFITmarsProfile(OMFITnColumns):
     pass
 
-
 ############################################
 if '__main__' == __name__:
     test_classes_main_header()
