@@ -12,6 +12,7 @@ except ImportError as _excp:
     else:
         raise
 
+from omfit_classes.utils_base import _streams
 from omfit_classes.omfit_json import OMFITjson
 from omfit_classes.omfit_base import OMFITexpression, evalExpr
 from omfit_classes.omfit_mds import translate_MDSserver, tunneled_MDSserver
@@ -35,13 +36,49 @@ except AttributeError:
     # avoid OMFIT crashing if OMAS version is not the latest
     pass
 
+# hook up omfit and omas print streams
+omas.omas_utils._streams = _streams
+
 # export __all__ from omas.__all__
 __all__ = list([x for x in ['omas'] + list(omas.__dict__.keys()) if not x.startswith('_')])
 
 
-def _base_omas_remote(serverPicker, target_function, python_script='from omas import *',
-                      python_prelude=None, python_command=None, quiet=False, forceRemote=False,
-                      IMAS_module=None, OMAS_module=None, UDA_module=None, **kw):
+def pprint_imas_data_dictionary_info(location):
+    '''
+    pretty print IMAS data dictionary info
+
+    :param location: location in IMAS data dictionary
+    '''
+    location = omas.omas_utils.p2l(location)
+    location = omas.omas_utils.l2u(location)
+    info = omas_info_node(location.rstrip('.:'))
+    printi('\n' + location)
+    printi('-' * len(location))
+    prioritize = ['documentation', 'units', 'data_type', 'coordinates']
+    skip = ['full_path', 'structure_reference', 'type']
+    for item in prioritize:
+        if item in info:
+            printi(f'* {item}: ', end='')
+            print(f'{info[item]}')
+    for item in sorted(info):
+        if item not in prioritize + skip:
+            printi(f'* {item}: ', end='')
+            print(f'{info[item]}')
+
+
+def _base_omas_remote(
+    serverPicker,
+    target_function,
+    python_script='from omas import *',
+    python_prelude=None,
+    python_command=None,
+    quiet=False,
+    forceRemote=False,
+    IMAS_module=None,
+    OMAS_module=None,
+    UDA_module=None,
+    **kw,
+):
     r"""
     low-level function that uses OMFITx.remote_python to interface with remote IMAS servers
 
@@ -184,25 +221,29 @@ imasdb {machine}
         kw['user'] = user
 
     # substitute format strings
-    python = python_prelude.strip().format(machine=kw.get('machine', ''),
-                                           IMAS_module=IMAS_module,
-                                           OMAS_module=OMAS_module,
-                                           UDA_module=UDA_module,
-                                           user=user) + '\nexport OMAS_DEBUG_STDOUT=1\n' + python_command
+    python = (
+        python_prelude.strip().format(
+            machine=kw.get('machine', ''), IMAS_module=IMAS_module, OMAS_module=OMAS_module, UDA_module=UDA_module, user=user
+        )
+        + '\nexport OMAS_DEBUG_STDOUT=1\n'
+        + python_command
+    )
 
     import omfit_classes.OMFITx as OMFITx
-    return OMFITx.remote_python(None,
-                                executable=python + ' -u %s',
-                                python_script=python_script,
-                                target_function=target_function,
-                                workdir='./',
-                                server=SERVER[serverPicker]['server'],
-                                tunnel=SERVER[serverPicker]['tunnel'],
-                                remotedir=os.path.abspath(str(SERVER[serverPicker]['workdir']) + os.sep + 'OMAS_tmp') + os.sep,
-                                namespace=kw,
-                                quiet=quiet,
-                                forceRemote=forceRemote
-                                )
+
+    return OMFITx.remote_python(
+        None,
+        executable=python + ' -u %s',
+        python_script=python_script,
+        target_function=target_function,
+        workdir='./',
+        server=SERVER[serverPicker]['server'],
+        tunnel=SERVER[serverPicker]['tunnel'],
+        remotedir=os.path.abspath(str(SERVER[serverPicker]['workdir']) + os.sep + 'OMAS_tmp') + os.sep,
+        namespace=kw,
+        quiet=quiet,
+        forceRemote=forceRemote,
+    )
 
 
 def save_omas_imas_remote(serverPicker, ods, **kw):
@@ -351,23 +392,53 @@ def iter_scenario_summary_remote(quiet=False, environment="module purge\nmodule
 
     # fields to be read
     # 'composition',
-    what = ['ref_name', 'ro_name', 'shot', 'run', 'type', 'workflow', 'database', 'confinement', 'ip', 'b0', 'fuelling', 'ne0', 'zeff', 'npeak', 'p_hcd', 'p_ec', 'p_ic', 'p_nbi', 'p_lh', 'location', 'idslist']
+    what = [
+        'ref_name',
+        'ro_name',
+        'shot',
+        'run',
+        'type',
+        'workflow',
+        'database',
+        'confinement',
+        'ip',
+        'b0',
+        'fuelling',
+        'ne0',
+        'zeff',
+        'npeak',
+        'p_hcd',
+        'p_ec',
+        'p_ic',
+        'p_nbi',
+        'p_lh',
+        'location',
+        'idslist',
+    ]
 
     # execute scenario_summary remotely
-    executable = environment + '''
+    executable = (
+        environment
+        + '''
 scenario_summary -c {what}
-'''.format(what=','.join(what))
+'''.format(
+            what=','.join(what)
+        )
+    )
     std_out = []
     std_err = []
     import omfit_classes.OMFITx as OMFITx
+
     try:
-        OMFITx.remote_execute(SERVER['iter_login']['server'],
-                              executable,
-                              './',
-                              tunnel=SERVER['iter_login']['tunnel'],
-                              std_out=std_out,
-                              std_err=std_err,
-                              quiet=True)
+        OMFITx.remote_execute(
+            SERVER['iter_login']['server'],
+            executable,
+            './',
+            tunnel=SERVER['iter_login']['tunnel'],
+            std_out=std_out,
+            std_err=std_err,
+            quiet=True,
+        )
         # identify scenario_summary block
         # (read data in reverse order because the ITER terminal prints out a lot of unwanted infos when connecting)
         count = 0
@@ -379,21 +450,21 @@ scenario_summary -c {what}
         header = std_out[-k - 2]
         headers = re.sub(r'\s\s+', '\t', header).strip().split('\t')
         header_start = [header.index(h) for h in headers] + [None]
-        scenario_summary = std_out[-k:len(std_out) - count - 1]
+        scenario_summary = std_out[-k : len(std_out) - count - 1]
     except Exception:
         tag_print('\n'.join(std_out), tag='PROGRAM_OUT')
         tag_print('\n'.join(std_err), tag='PROGRAM_ERR')
         raise
     # print original output to screen
     if not quiet:
-        print('\n'.join(std_out[-k - 3:len(std_out) - count]))
+        print('\n'.join(std_out[-k - 3 : len(std_out) - count]))
 
     # parse scenario_summary output
     scenarios = OMFITiterscenario('iter_scenarios.json')
     for li, line in enumerate(scenario_summary):
         items = []
         for hi, start in enumerate(header_start[:-1]):
-            items.append(line[start:header_start[hi + 1]].strip())
+            items.append(line[start : header_start[hi + 1]].strip())
         if len(items) != len(headers):
             print('items=', items)
             print('headers=', headers)
@@ -448,8 +519,18 @@ class OMFITods(OMFITobject, ODS):
 
     def __getstate__(self):
         from omas.omas_core import omas_dictstate
+
         state = {}
-        for item in omas_dictstate + ['OMFITproperties', 'dynaLoad', 'modifyOriginal', 'readOnly', 'file_type', 'originalFilename', 'filename', 'link']:
+        for item in omas_dictstate + [
+            'OMFITproperties',
+            'dynaLoad',
+            'modifyOriginal',
+            'readOnly',
+            'file_type',
+            'originalFilename',
+            'filename',
+            'link',
+        ]:
             if item in self.__dict__:
                 state[item] = self.__dict__[item]
         return state
@@ -467,21 +548,28 @@ class OMFITods(OMFITobject, ODS):
 
     for func in ods_method_list:
         if func not in ['save', 'load']:
-            exec('''
+            exec(
+                '''
 def {func}(self, *args, **kw):
     r"""{doc}"""
     dynaLoader(self)
     return ODS.{func}(self, *args, **kw)
-'''.format(func=func, doc=getattr(ODS, func).__doc__))
+'''.format(
+                    func=func, doc=getattr(ODS, func).__doc__
+                )
+            )
+
 
 # use OMFIT MDS+ tunneling within OMAS
 if compare_version(omas.__version__, '0.70') >= 0:
+
     def mds_machine_to_server_mapping(machine, treename, quiet=False):
         server0 = translate_MDSserver(machine, treename)
         tunneled_server = tunneled_MDSserver(server0, quiet=quiet)
         return tunneled_server
 
     from omas import omas_machine
+
     omas.omas_machine.mds_machine_to_server_mapping = mds_machine_to_server_mapping
 
 __all__.extend(
@@ -493,7 +581,8 @@ __all__.extend(
         'iter_scenario_summary_remote',
         'load_omas_iter_scenario_remote',
         'OMFITiterscenario',
-        'OMFITods'
+        'OMFITods',
+        'pprint_imas_data_dictionary_info',
     ]
 )
 
