@@ -831,7 +831,15 @@ class OMFITpFile(SortedDict, OMFITascii):
                 quants += [(f'nz{pk}', f'ion.{k}.density_thermal', 1e-20)]
 
         # load gEQDSK from ODS
-        gEQDSK = OMFITgeqdsk('g0.0').from_omas(ods)
+        # Need to identify correct time.
+        gEQDSK = OMFITgeqdsk('g0.0').from_omas(ods, time_index=time_index)
+        gtime = ods[f'equilibrium.time_slice.{time_index}.time']
+        if gtime != prof1d['time']:
+            printw("Warning: The time corresponding to the equilibrium and the profile is mismatched!")
+            printw(f"    Please check your input ods!")
+            printw(
+                f"    For time_index = {time_index}, the equilibrium has time = {gtime}, and the core_profile has time = {prof1d['time']}."
+            )
 
         # load data from ODS
         with omas_environment(ods, cocosio=cocosio):
@@ -855,9 +863,9 @@ class OMFITpFile(SortedDict, OMFITascii):
                     if isinstance(q_ods, list):
                         self[q_p]['data'] = 0.0 * psin
                         for i, qo in enumerate(q_ods):
-                            self[q_p]['data'] += fac[i] * prof1d[qo]
+                            self[q_p]['data'] += fac[i] * nominal_values(prof1d[qo])
                     else:
-                        self[q_p]['data'] = fac * prof1d[q_ods]
+                        self[q_p]['data'] = fac * nominal_values(prof1d[q_ods])
                 except ValueError:
                     self[q_p]['data'] = 0.0 * psin
 
@@ -886,38 +894,65 @@ class OMFITpFile(SortedDict, OMFITascii):
                     missing = []
 
                     if f'ion.{k}.rotation.parallel_stream_function' in prof1d:
-                        kpol = 1e-3 * prof1d[f'ion.{k}.rotation.parallel_stream_function']
+                        kpol = 1e-3 * nominal_values(prof1d[f'ion.{k}.rotation.parallel_stream_function'])
                         omegp = -Bt * kpol / R
                         vpol = sign_Ip * kpol * Bp  # sign_Ip accounts for pFile definition
 
+                    if f'ion.{k}.rotation_frequency_tor' in prof1d:
+                        omeg = 1e-3 * nominal_values(prof1d[f'ion.{k}.rotation_frequency_tor'])
+
                     if f'ion.{k}.rotation.perpendicular' in prof1d:
-                        omgvb = 1e-3 * prof1d[f'ion.{k}.rotation.perpendicular']
+                        omgvb = 1e-3 * nominal_values(prof1d[f'ion.{k}.rotation.perpendicular'])
 
                     if f'ion.{k}.rotation.diamagnetic' in prof1d:
                         # sign_Ip accounts for abs(dpsi) in pFile definition
-                        omgpp = 1e-3 * sign_Ip * prof1d[f'ion.{k}.rotation.diamagnetic']
+                        omgpp = -1e-3 * sign_Ip * nominal_values(prof1d[f'ion.{k}.rotation.diamagnetic'])
 
-                    if omegp is not None:
-                        if (omgvb is None) and (omgpp is not None):
-                            # sign_Ip accounts for pFile definition
-                            omgvb = sign_Ip * (self['omgeb'] - omgpp)
+                    omgeb = self['omgeb']['data']
+                    if (omgvb is None) and (omeg is not None) and (omegp is not None):
+                        omgvb = omeg + omegp
 
-                        if omgvb is not None:
-                            omeg = omgvb - omegp
-                            vtor = R * omeg
-                            if omgpp is None:
-                                # sign_Ip accounts pFile definition
-                                omgpp = self['omgeb'] - sign_Ip * omgvb
+                    if (not np.any(omgeb)) and (omgpp is not None) and (omgvb is not None):
+                        omgeb = omgpp + sign_Ip * omgvb
+
+                    if omeg is None and omgvb is not None and omegp is not None:
+                        omeg = omgvb - omegp
+
+                    if omeg is not None:
+                        vtor = R * omeg
+                        if omgpp is None:
+                            # sign_Ip accounts pFile definition
+                            omgpp = omgeb - sign_Ip * omgvb
 
                     if vpol is None and f'ion.{k}.velocity.poloidal' in prof1d:
-                        vpol = 1e-3 * prof1d[f'ion.{k}.velocity.poloidal']
+                        vpol = 1e-3 * nominal_values(prof1d[f'ion.{k}.velocity.poloidal'])
 
                     if vtor is None and f'ion.{k}.velocity.toroidal' in prof1d:
-                        vtor = 1e-3 * prof1d[f'ion.{k}.velocity.toroidal']
+                        vtor = 1e-3 * nominal_values(prof1d[f'ion.{k}.velocity.toroidal'])
+
+                    # Calculate fallback omevb and ommvb
+                    omevb = self['omevb']['data']  # These are in params above and will be present, but may be all zero
+                    omepp = self['omepp']['data']
+                    ommvb = self['ommvb']['data']
+                    ommpp = self['ommpp']['data']
+
+                    if (not np.any(omevb)) and (omepp is not None) and np.any(omgeb):
+                        omevb = sign_Ip * (omgeb - omepp)
+                    if (not np.any(ommvb)) and (ommpp is not None) and np.any(omgeb):
+                        ommvb = sign_Ip * (omgeb - ommpp)
 
                     params = [(f'vpol{ik}', vpol), (f'vtor{ik}', vtor)]
                     if ik == 1:
-                        params += [('kpol', kpol), ('omegp', omegp), ('omgvb', omgvb), ('omeg', omeg), ('omgpp', omgpp)]
+                        params += [
+                            ('kpol', kpol),
+                            ('omegp', omegp),
+                            ('omgvb', omgvb),
+                            ('omeg', omeg),
+                            ('omgpp', omgpp),
+                            ('omevb', omevb),
+                            ('ommvb', ommvb),
+                            ('omgeb', omgeb),
+                        ]
 
                     for name, val in params:
                         self[name]['psinorm'] = psin
